# Library for interacting with files and data in yaml format 

[By Marc Jose Rubio](https://github.com/toshuomj)

Library for interacting with files and data in yaml format

## 💡 Prerequisites

   [Python 3](https://www.python.org/downloads/release/python-3101/)

## 📚 Example of use

```
from akiraPyYaml import read_yaml_from_file

read_yaml_from_file('file.yaml')
```

[Donate](paypal.me/marcjose1)
